import { 
  select, 
  csv, 
  scaleLinear, 
  scaleBand,
  scaleTime,
  max,
  axisLeft,
  axisBottom,
  format,
  area,
  extent
} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  
  const title = 'Urban population in Romania';
  
  const xValue = d => d.Year;
  const xAxisLabel = 'Year';
  
  const yValue = d => d.Urban_population; 
  const yAxisLabel = 'Urban population';
  
  const margin = {top: 50, right: 40, bottom: 90, left: 140};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain([0, max(data, yValue)]) 
  	.range([0, innerHeight].reverse())
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const yAxisTickFormat = number => 
  	format('.2s')(number)
  		.replace('G', 'B')
  		.replace('.0', '');
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.ticks(5)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickFormat(yAxisTickFormat)
  	.tickSize(-innerWidth)
  	.ticks(5)
  	.tickPadding(15);
  
  const yAxisG = g.append('g')
    .call(yAxis);
  
  yAxisG
  	.selectAll('.domain')
    	.remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  	xAxisG.select('.domain').remove();
  
  const areaGenerathor = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  
  g.append('path')
  	.attr('class', 'area-path')
  	.attr('d', areaGenerathor(data));
  
  g.append('text')
  	.text(title)
  	.attr('y', -10)
  	.attr('class', 'plot-title');
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.text(xAxisLabel)
  	.attr('fill', 'black')
  	.attr('x', innerWidth / 2)
  	.attr('y', 70);
  
  
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.text(yAxisLabel)
  	.attr('fill', 'black')
  	.attr('x', -innerHeight/2)
  	.attr('text-anchor', 'middle')
  	.attr('y', -85)
  	.attr('transform', `rotate(-90)`);;
  
}

csv('data.csv').then(data => {
	data.forEach(d => {
    //"Year","GDP"
  	d.Urban_population = +d.Urban_population;
    d.Year = new Date(d.Year);
  });
  render(data);
});



























